GLASS = chr(0xf000)
MUSIC = chr(0xf001)
SEARCH = chr(0xf002)
ENVELOPE_O = chr(0xf003)
HEART = chr(0xf004)
STAR = chr(0xf005)
STAR_O = chr(0xf006)
USER = chr(0xf007)
FILM = chr(0xf008)
TH_LARGE = chr(0xf009)
TH = chr(0xf00a)
TH_LIST = chr(0xf00b)
CHECK = chr(0xf00c)
TIMES = chr(0xf00d)
SEARCH_PLUS = chr(0xf00e)
SEARCH_MINUS = chr(0xf010)
POWER_OFF = chr(0xf011)
SIGNAL = chr(0xf012)
COG = chr(0xf013)
TRASH_O = chr(0xf014)
HOME = chr(0xf015)
FILE_O = chr(0xf016)
CLOCK_O = chr(0xf017)
ROAD = chr(0xf018)
DOWNLOAD = chr(0xf019)
ARROW_CIRCLE_O_DOWN = chr(0xf01a)
ARROW_CIRCLE_O_UP = chr(0xf01b)
INBOX = chr(0xf01c)
PLAY_CIRCLE_O = chr(0xf01d)
REPEAT = chr(0xf01e)
REFRESH = chr(0xf021)
LIST_ALT = chr(0xf022)
LOCK = chr(0xf023)
FLAG = chr(0xf024)
HEADPHONES = chr(0xf025)
VOLUME_OFF = chr(0xf026)
VOLUME_DOWN = chr(0xf027)
VOLUME_UP = chr(0xf028)
QRCODE = chr(0xf029)
BARCODE = chr(0xf02a)
TAG = chr(0xf02b)
TAGS = chr(0xf02c)
BOOK = chr(0xf02d)
BOOKMARK = chr(0xf02e)
PRINT = chr(0xf02f)
CAMERA = chr(0xf030)
FONT = chr(0xf031)
BOLD = chr(0xf032)
ITALIC = chr(0xf033)
TEXT_HEIGHT = chr(0xf034)
TEXT_WIDTH = chr(0xf035)
ALIGN_LEFT = chr(0xf036)
ALIGN_CENTER = chr(0xf037)
ALIGN_RIGHT = chr(0xf038)
ALIGN_JUSTIFY = chr(0xf039)
LIST = chr(0xf03a)
OUTDENT = chr(0xf03b)
INDENT = chr(0xf03c)
VIDEO_CAMERA = chr(0xf03d)
PICTURE_O = chr(0xf03e)
PENCIL = chr(0xf040)
MAP_MARKER = chr(0xf041)
ADJUST = chr(0xf042)
TINT = chr(0xf043)
PENCIL_SQUARE_O = chr(0xf044)
SHARE_SQUARE_O = chr(0xf045)
CHECK_SQUARE_O = chr(0xf046)
ARROWS = chr(0xf047)
STEP_BACKWARD = chr(0xf048)
FAST_BACKWARD = chr(0xf049)
BACKWARD = chr(0xf04a)
PLAY = chr(0xf04b)
PAUSE = chr(0xf04c)
STOP = chr(0xf04d)
FORWARD = chr(0xf04e)
FAST_FORWARD = chr(0xf050)
STEP_FORWARD = chr(0xf051)
EJECT = chr(0xf052)
CHEVRON_LEFT = chr(0xf053)
CHEVRON_RIGHT = chr(0xf054)
PLUS_CIRCLE = chr(0xf055)
MINUS_CIRCLE = chr(0xf056)
TIMES_CIRCLE = chr(0xf057)
CHECK_CIRCLE = chr(0xf058)
QUESTION_CIRCLE = chr(0xf059)
INFO_CIRCLE = chr(0xf05a)
CROSSHAIRS = chr(0xf05b)
TIMES_CIRCLE_O = chr(0xf05c)
CHECK_CIRCLE_O = chr(0xf05d)
BAN = chr(0xf05e)
ARROW_LEFT = chr(0xf060)
ARROW_RIGHT = chr(0xf061)
ARROW_UP = chr(0xf062)
ARROW_DOWN = chr(0xf063)
SHARE = chr(0xf064)
EXPAND = chr(0xf065)
COMPRESS = chr(0xf066)
PLUS = chr(0xf067)
MINUS = chr(0xf068)
ASTERISK = chr(0xf069)
EXCLAMATION_CIRCLE = chr(0xf06a)
GIFT = chr(0xf06b)
LEAF = chr(0xf06c)
FIRE = chr(0xf06d)
EYE = chr(0xf06e)
EYE_SLASH = chr(0xf070)
EXCLAMATION_TRIANGLE = chr(0xf071)
PLANE = chr(0xf072)
CALENDAR = chr(0xf073)
RANDOM = chr(0xf074)
COMMENT = chr(0xf075)
MAGNET = chr(0xf076)
CHEVRON_UP = chr(0xf077)
CHEVRON_DOWN = chr(0xf078)
RETWEET = chr(0xf079)
SHOPPING_CART = chr(0xf07a)
FOLDER = chr(0xf07b)
FOLDER_OPEN = chr(0xf07c)
ARROWS_V = chr(0xf07d)
ARROWS_H = chr(0xf07e)
BAR_CHART = chr(0xf080)
TWITTER_SQUARE = chr(0xf081)
FACEBOOK_SQUARE = chr(0xf082)
CAMERA_RETRO = chr(0xf083)
KEY = chr(0xf084)
COGS = chr(0xf085)
COMMENTS = chr(0xf086)
THUMBS_O_UP = chr(0xf087)
THUMBS_O_DOWN = chr(0xf088)
STAR_HALF = chr(0xf089)
HEART_O = chr(0xf08a)
SIGN_OUT = chr(0xf08b)
LINKEDIN_SQUARE = chr(0xf08c)
THUMB_TACK = chr(0xf08d)
EXTERNAL_LINK = chr(0xf08e)
SIGN_IN = chr(0xf090)
TROPHY = chr(0xf091)
GITHUB_SQUARE = chr(0xf092)
UPLOAD = chr(0xf093)
LEMON_O = chr(0xf094)
PHONE = chr(0xf095)
SQUARE_O = chr(0xf096)
BOOKMARK_O = chr(0xf097)
PHONE_SQUARE = chr(0xf098)
TWITTER = chr(0xf099)
FACEBOOK = chr(0xf09a)
GITHUB = chr(0xf09b)
UNLOCK = chr(0xf09c)
CREDIT_CARD = chr(0xf09d)
RSS = chr(0xf09e)
HDD_O = chr(0xf0a0)
BULLHORN = chr(0xf0a1)
BELL = chr(0xf0f3)
CERTIFICATE = chr(0xf0a3)
HAND_O_RIGHT = chr(0xf0a4)
HAND_O_LEFT = chr(0xf0a5)
HAND_O_UP = chr(0xf0a6)
HAND_O_DOWN = chr(0xf0a7)
ARROW_CIRCLE_LEFT = chr(0xf0a8)
ARROW_CIRCLE_RIGHT = chr(0xf0a9)
ARROW_CIRCLE_UP = chr(0xf0aa)
ARROW_CIRCLE_DOWN = chr(0xf0ab)
GLOBE = chr(0xf0ac)
WRENCH = chr(0xf0ad)
TASKS = chr(0xf0ae)
FILTER = chr(0xf0b0)
BRIEFCASE = chr(0xf0b1)
ARROWS_ALT = chr(0xf0b2)
USERS = chr(0xf0c0)
LINK = chr(0xf0c1)
CLOUD = chr(0xf0c2)
FLASK = chr(0xf0c3)
SCISSORS = chr(0xf0c4)
FILES_O = chr(0xf0c5)
PAPERCLIP = chr(0xf0c6)
FLOPPY_O = chr(0xf0c7)
SQUARE = chr(0xf0c8)
BARS = chr(0xf0c9)
LIST_UL = chr(0xf0ca)
LIST_OL = chr(0xf0cb)
STRIKETHROUGH = chr(0xf0cc)
UNDERLINE = chr(0xf0cd)
TABLE = chr(0xf0ce)
MAGIC = chr(0xf0d0)
TRUCK = chr(0xf0d1)
PINTEREST = chr(0xf0d2)
PINTEREST_SQUARE = chr(0xf0d3)
GOOGLE_PLUS_SQUARE = chr(0xf0d4)
GOOGLE_PLUS = chr(0xf0d5)
MONEY = chr(0xf0d6)
CARET_DOWN = chr(0xf0d7)
CARET_UP = chr(0xf0d8)
CARET_LEFT = chr(0xf0d9)
CARET_RIGHT = chr(0xf0da)
COLUMNS = chr(0xf0db)
SORT = chr(0xf0dc)
SORT_DESC = chr(0xf0dd)
SORT_ASC = chr(0xf0de)
ENVELOPE = chr(0xf0e0)
LINKEDIN = chr(0xf0e1)
UNDO = chr(0xf0e2)
GAVEL = chr(0xf0e3)
TACHOMETER = chr(0xf0e4)
COMMENT_O = chr(0xf0e5)
COMMENTS_O = chr(0xf0e6)
BOLT = chr(0xf0e7)
SITEMAP = chr(0xf0e8)
UMBRELLA = chr(0xf0e9)
CLIPBOARD = chr(0xf0ea)
LIGHTBULB_O = chr(0xf0eb)
EXCHANGE = chr(0xf0ec)
CLOUD_DOWNLOAD = chr(0xf0ed)
CLOUD_UPLOAD = chr(0xf0ee)
USER_MD = chr(0xf0f0)
STETHOSCOPE = chr(0xf0f1)
SUITCASE = chr(0xf0f2)
BELL_O = chr(0xf0a2)
COFFEE = chr(0xf0f4)
CUTLERY = chr(0xf0f5)
FILE_TEXT_O = chr(0xf0f6)
BUILDING_O = chr(0xf0f7)
HOSPITAL_O = chr(0xf0f8)
AMBULANCE = chr(0xf0f9)
MEDKIT = chr(0xf0fa)
FIGHTER_JET = chr(0xf0fb)
BEER = chr(0xf0fc)
H_SQUARE = chr(0xf0fd)
PLUS_SQUARE = chr(0xf0fe)
ANGLE_DOUBLE_LEFT = chr(0xf100)
ANGLE_DOUBLE_RIGHT = chr(0xf101)
ANGLE_DOUBLE_UP = chr(0xf102)
ANGLE_DOUBLE_DOWN = chr(0xf103)
ANGLE_LEFT = chr(0xf104)
ANGLE_RIGHT = chr(0xf105)
ANGLE_UP = chr(0xf106)
ANGLE_DOWN = chr(0xf107)
DESKTOP = chr(0xf108)
LAPTOP = chr(0xf109)
TABLET = chr(0xf10a)
MOBILE = chr(0xf10b)
CIRCLE_O = chr(0xf10c)
QUOTE_LEFT = chr(0xf10d)
QUOTE_RIGHT = chr(0xf10e)
SPINNER = chr(0xf110)
CIRCLE = chr(0xf111)
REPLY = chr(0xf112)
GITHUB_ALT = chr(0xf113)
FOLDER_O = chr(0xf114)
FOLDER_OPEN_O = chr(0xf115)
SMILE_O = chr(0xf118)
FROWN_O = chr(0xf119)
MEH_O = chr(0xf11a)
GAMEPAD = chr(0xf11b)
KEYBOARD_O = chr(0xf11c)
FLAG_O = chr(0xf11d)
FLAG_CHECKERED = chr(0xf11e)
TERMINAL = chr(0xf120)
CODE = chr(0xf121)
REPLY_ALL = chr(0xf122)
STAR_HALF_O = chr(0xf123)
LOCATION_ARROW = chr(0xf124)
CROP = chr(0xf125)
CODE_FORK = chr(0xf126)
CHAIN_BROKEN = chr(0xf127)
QUESTION = chr(0xf128)
INFO = chr(0xf129)
EXCLAMATION = chr(0xf12a)
SUPERSCRIPT = chr(0xf12b)
SUBSCRIPT = chr(0xf12c)
ERASER = chr(0xf12d)
PUZZLE_PIECE = chr(0xf12e)
MICROPHONE = chr(0xf130)
MICROPHONE_SLASH = chr(0xf131)
SHIELD = chr(0xf132)
CALENDAR_O = chr(0xf133)
FIRE_EXTINGUISHER = chr(0xf134)
ROCKET = chr(0xf135)
MAXCDN = chr(0xf136)
CHEVRON_CIRCLE_LEFT = chr(0xf137)
CHEVRON_CIRCLE_RIGHT = chr(0xf138)
CHEVRON_CIRCLE_UP = chr(0xf139)
CHEVRON_CIRCLE_DOWN = chr(0xf13a)
HTML5 = chr(0xf13b)
CSS3 = chr(0xf13c)
ANCHOR = chr(0xf13d)
UNLOCK_ALT = chr(0xf13e)
BULLSEYE = chr(0xf140)
ELLIPSIS_H = chr(0xf141)
ELLIPSIS_V = chr(0xf142)
RSS_SQUARE = chr(0xf143)
PLAY_CIRCLE = chr(0xf144)
TICKET = chr(0xf145)
MINUS_SQUARE = chr(0xf146)
MINUS_SQUARE_O = chr(0xf147)
LEVEL_UP = chr(0xf148)
LEVEL_DOWN = chr(0xf149)
CHECK_SQUARE = chr(0xf14a)
PENCIL_SQUARE = chr(0xf14b)
EXTERNAL_LINK_SQUARE = chr(0xf14c)
SHARE_SQUARE = chr(0xf14d)
COMPASS = chr(0xf14e)
CARET_SQUARE_O_DOWN = chr(0xf150)
CARET_SQUARE_O_UP = chr(0xf151)
CARET_SQUARE_O_RIGHT = chr(0xf152)
EUR = chr(0xf153)
GBP = chr(0xf154)
USD = chr(0xf155)
INR = chr(0xf156)
JPY = chr(0xf157)
RUB = chr(0xf158)
KRW = chr(0xf159)
BTC = chr(0xf15a)
FILE = chr(0xf15b)
FILE_TEXT = chr(0xf15c)
SORT_ALPHA_ASC = chr(0xf15d)
SORT_ALPHA_DESC = chr(0xf15e)
SORT_AMOUNT_ASC = chr(0xf160)
SORT_AMOUNT_DESC = chr(0xf161)
SORT_NUMERIC_ASC = chr(0xf162)
SORT_NUMERIC_DESC = chr(0xf163)
THUMBS_UP = chr(0xf164)
THUMBS_DOWN = chr(0xf165)
YOUTUBE_SQUARE = chr(0xf166)
YOUTUBE = chr(0xf167)
XING = chr(0xf168)
XING_SQUARE = chr(0xf169)
YOUTUBE_PLAY = chr(0xf16a)
DROPBOX = chr(0xf16b)
STACK_OVERFLOW = chr(0xf16c)
INSTAGRAM = chr(0xf16d)
FLICKR = chr(0xf16e)
ADN = chr(0xf170)
BITBUCKET = chr(0xf171)
BITBUCKET_SQUARE = chr(0xf172)
TUMBLR = chr(0xf173)
TUMBLR_SQUARE = chr(0xf174)
LONG_ARROW_DOWN = chr(0xf175)
LONG_ARROW_UP = chr(0xf176)
LONG_ARROW_LEFT = chr(0xf177)
LONG_ARROW_RIGHT = chr(0xf178)
APPLE = chr(0xf179)
WINDOWS = chr(0xf17a)
ANDROID = chr(0xf17b)
LINUX = chr(0xf17c)
DRIBBBLE = chr(0xf17d)
SKYPE = chr(0xf17e)
FOURSQUARE = chr(0xf180)
TRELLO = chr(0xf181)
FEMALE = chr(0xf182)
MALE = chr(0xf183)
GRATIPAY = chr(0xf184)
SUN_O = chr(0xf185)
MOON_O = chr(0xf186)
ARCHIVE = chr(0xf187)
BUG = chr(0xf188)
VK = chr(0xf189)
WEIBO = chr(0xf18a)
RENREN = chr(0xf18b)
PAGELINES = chr(0xf18c)
STACK_EXCHANGE = chr(0xf18d)
ARROW_CIRCLE_O_RIGHT = chr(0xf18e)
ARROW_CIRCLE_O_LEFT = chr(0xf190)
CARET_SQUARE_O_LEFT = chr(0xf191)
DOT_CIRCLE_O = chr(0xf192)
WHEELCHAIR = chr(0xf193)
VIMEO_SQUARE = chr(0xf194)
TRY = chr(0xf195)
PLUS_SQUARE_O = chr(0xf196)
SPACE_SHUTTLE = chr(0xf197)
SLACK = chr(0xf198)
ENVELOPE_SQUARE = chr(0xf199)
WORDPRESS = chr(0xf19a)
OPENID = chr(0xf19b)
UNIVERSITY = chr(0xf19c)
GRADUATION_CAP = chr(0xf19d)
YAHOO = chr(0xf19e)
GOOGLE = chr(0xf1a0)
REDDIT = chr(0xf1a1)
REDDIT_SQUARE = chr(0xf1a2)
STUMBLEUPON_CIRCLE = chr(0xf1a3)
STUMBLEUPON = chr(0xf1a4)
DELICIOUS = chr(0xf1a5)
DIGG = chr(0xf1a6)
PIED_PIPER_PP = chr(0xf1a7)
PIED_PIPER_ALT = chr(0xf1a8)
DRUPAL = chr(0xf1a9)
JOOMLA = chr(0xf1aa)
LANGUAGE = chr(0xf1ab)
FAX = chr(0xf1ac)
BUILDING = chr(0xf1ad)
CHILD = chr(0xf1ae)
PAW = chr(0xf1b0)
SPOON = chr(0xf1b1)
CUBE = chr(0xf1b2)
CUBES = chr(0xf1b3)
BEHANCE = chr(0xf1b4)
BEHANCE_SQUARE = chr(0xf1b5)
STEAM = chr(0xf1b6)
STEAM_SQUARE = chr(0xf1b7)
RECYCLE = chr(0xf1b8)
CAR = chr(0xf1b9)
TAXI = chr(0xf1ba)
TREE = chr(0xf1bb)
SPOTIFY = chr(0xf1bc)
DEVIANTART = chr(0xf1bd)
SOUNDCLOUD = chr(0xf1be)
DATABASE = chr(0xf1c0)
FILE_PDF_O = chr(0xf1c1)
FILE_WORD_O = chr(0xf1c2)
FILE_EXCEL_O = chr(0xf1c3)
FILE_POWERPOINT_O = chr(0xf1c4)
FILE_IMAGE_O = chr(0xf1c5)
FILE_ARCHIVE_O = chr(0xf1c6)
FILE_AUDIO_O = chr(0xf1c7)
FILE_VIDEO_O = chr(0xf1c8)
FILE_CODE_O = chr(0xf1c9)
VINE = chr(0xf1ca)
CODEPEN = chr(0xf1cb)
JSFIDDLE = chr(0xf1cc)
LIFE_RING = chr(0xf1cd)
CIRCLE_O_NOTCH = chr(0xf1ce)
REBEL = chr(0xf1d0)
EMPIRE = chr(0xf1d1)
GIT_SQUARE = chr(0xf1d2)
GIT = chr(0xf1d3)
HACKER_NEWS = chr(0xf1d4)
TENCENT_WEIBO = chr(0xf1d5)
QQ = chr(0xf1d6)
WEIXIN = chr(0xf1d7)
PAPER_PLANE = chr(0xf1d8)
PAPER_PLANE_O = chr(0xf1d9)
HISTORY = chr(0xf1da)
CIRCLE_THIN = chr(0xf1db)
HEADER = chr(0xf1dc)
PARAGRAPH = chr(0xf1dd)
SLIDERS = chr(0xf1de)
SHARE_ALT = chr(0xf1e0)
SHARE_ALT_SQUARE = chr(0xf1e1)
BOMB = chr(0xf1e2)
FUTBOL_O = chr(0xf1e3)
TTY = chr(0xf1e4)
BINOCULARS = chr(0xf1e5)
PLUG = chr(0xf1e6)
SLIDESHARE = chr(0xf1e7)
TWITCH = chr(0xf1e8)
YELP = chr(0xf1e9)
NEWSPAPER_O = chr(0xf1ea)
WIFI = chr(0xf1eb)
CALCULATOR = chr(0xf1ec)
PAYPAL = chr(0xf1ed)
GOOGLE_WALLET = chr(0xf1ee)
CC_VISA = chr(0xf1f0)
CC_MASTERCARD = chr(0xf1f1)
CC_DISCOVER = chr(0xf1f2)
CC_AMEX = chr(0xf1f3)
CC_PAYPAL = chr(0xf1f4)
CC_STRIPE = chr(0xf1f5)
BELL_SLASH = chr(0xf1f6)
BELL_SLASH_O = chr(0xf1f7)
TRASH = chr(0xf1f8)
COPYRIGHT = chr(0xf1f9)
AT = chr(0xf1fa)
EYEDROPPER = chr(0xf1fb)
PAINT_BRUSH = chr(0xf1fc)
BIRTHDAY_CAKE = chr(0xf1fd)
AREA_CHART = chr(0xf1fe)
PIE_CHART = chr(0xf200)
LINE_CHART = chr(0xf201)
LASTFM = chr(0xf202)
LASTFM_SQUARE = chr(0xf203)
TOGGLE_OFF = chr(0xf204)
TOGGLE_ON = chr(0xf205)
BICYCLE = chr(0xf206)
BUS = chr(0xf207)
IOXHOST = chr(0xf208)
ANGELLIST = chr(0xf209)
CC = chr(0xf20a)
ILS = chr(0xf20b)
MEANPATH = chr(0xf20c)
BUYSELLADS = chr(0xf20d)
CONNECTDEVELOP = chr(0xf20e)
DASHCUBE = chr(0xf210)
FORUMBEE = chr(0xf211)
LEANPUB = chr(0xf212)
SELLSY = chr(0xf213)
SHIRTSINBULK = chr(0xf214)
SIMPLYBUILT = chr(0xf215)
SKYATLAS = chr(0xf216)
CART_PLUS = chr(0xf217)
CART_ARROW_DOWN = chr(0xf218)
DIAMOND = chr(0xf219)
SHIP = chr(0xf21a)
USER_SECRET = chr(0xf21b)
MOTORCYCLE = chr(0xf21c)
STREET_VIEW = chr(0xf21d)
HEARTBEAT = chr(0xf21e)
VENUS = chr(0xf221)
MARS = chr(0xf222)
MERCURY = chr(0xf223)
TRANSGENDER = chr(0xf224)
TRANSGENDER_ALT = chr(0xf225)
VENUS_DOUBLE = chr(0xf226)
MARS_DOUBLE = chr(0xf227)
VENUS_MARS = chr(0xf228)
MARS_STROKE = chr(0xf229)
MARS_STROKE_V = chr(0xf22a)
MARS_STROKE_H = chr(0xf22b)
NEUTER = chr(0xf22c)
GENDERLESS = chr(0xf22d)
FACEBOOK_OFFICIAL = chr(0xf230)
PINTEREST_P = chr(0xf231)
WHATSAPP = chr(0xf232)
SERVER = chr(0xf233)
USER_PLUS = chr(0xf234)
USER_TIMES = chr(0xf235)
BED = chr(0xf236)
VIACOIN = chr(0xf237)
TRAIN = chr(0xf238)
SUBWAY = chr(0xf239)
MEDIUM = chr(0xf23a)
Y_COMBINATOR = chr(0xf23b)
OPTIN_MONSTER = chr(0xf23c)
OPENCART = chr(0xf23d)
EXPEDITEDSSL = chr(0xf23e)
BATTERY_FULL = chr(0xf240)
BATTERY_THREE_QUARTERS = chr(0xf241)
BATTERY_HALF = chr(0xf242)
BATTERY_QUARTER = chr(0xf243)
BATTERY_EMPTY = chr(0xf244)
MOUSE_POINTER = chr(0xf245)
I_CURSOR = chr(0xf246)
OBJECT_GROUP = chr(0xf247)
OBJECT_UNGROUP = chr(0xf248)
STICKY_NOTE = chr(0xf249)
STICKY_NOTE_O = chr(0xf24a)
CC_JCB = chr(0xf24b)
CC_DINERS_CLUB = chr(0xf24c)
CLONE = chr(0xf24d)
BALANCE_SCALE = chr(0xf24e)
HOURGLASS_O = chr(0xf250)
HOURGLASS_START = chr(0xf251)
HOURGLASS_HALF = chr(0xf252)
HOURGLASS_END = chr(0xf253)
HOURGLASS = chr(0xf254)
HAND_ROCK_O = chr(0xf255)
HAND_PAPER_O = chr(0xf256)
HAND_SCISSORS_O = chr(0xf257)
HAND_LIZARD_O = chr(0xf258)
HAND_SPOCK_O = chr(0xf259)
HAND_POINTER_O = chr(0xf25a)
HAND_PEACE_O = chr(0xf25b)
TRADEMARK = chr(0xf25c)
REGISTERED = chr(0xf25d)
CREATIVE_COMMONS = chr(0xf25e)
GG = chr(0xf260)
GG_CIRCLE = chr(0xf261)
TRIPADVISOR = chr(0xf262)
ODNOKLASSNIKI = chr(0xf263)
ODNOKLASSNIKI_SQUARE = chr(0xf264)
GET_POCKET = chr(0xf265)
WIKIPEDIA_W = chr(0xf266)
SAFARI = chr(0xf267)
CHROME = chr(0xf268)
FIREFOX = chr(0xf269)
OPERA = chr(0xf26a)
INTERNET_EXPLORER = chr(0xf26b)
TELEVISION = chr(0xf26c)
CONTAO = chr(0xf26d)
_500PX = chr(0xf26e)
AMAZON = chr(0xf270)
CALENDAR_PLUS_O = chr(0xf271)
CALENDAR_MINUS_O = chr(0xf272)
CALENDAR_TIMES_O = chr(0xf273)
CALENDAR_CHECK_O = chr(0xf274)
INDUSTRY = chr(0xf275)
MAP_PIN = chr(0xf276)
MAP_SIGNS = chr(0xf277)
MAP_O = chr(0xf278)
MAP = chr(0xf279)
COMMENTING = chr(0xf27a)
COMMENTING_O = chr(0xf27b)
HOUZZ = chr(0xf27c)
VIMEO = chr(0xf27d)
BLACK_TIE = chr(0xf27e)
FONTICONS = chr(0xf280)
REDDIT_ALIEN = chr(0xf281)
EDGE = chr(0xf282)
CREDIT_CARD_ALT = chr(0xf283)
CODIEPIE = chr(0xf284)
MODX = chr(0xf285)
FORT_AWESOME = chr(0xf286)
USB = chr(0xf287)
PRODUCT_HUNT = chr(0xf288)
MIXCLOUD = chr(0xf289)
SCRIBD = chr(0xf28a)
PAUSE_CIRCLE = chr(0xf28b)
PAUSE_CIRCLE_O = chr(0xf28c)
STOP_CIRCLE = chr(0xf28d)
STOP_CIRCLE_O = chr(0xf28e)
SHOPPING_BAG = chr(0xf290)
SHOPPING_BASKET = chr(0xf291)
HASHTAG = chr(0xf292)
BLUETOOTH = chr(0xf293)
BLUETOOTH_B = chr(0xf294)
PERCENT = chr(0xf295)
GITLAB = chr(0xf296)
WPBEGINNER = chr(0xf297)
WPFORMS = chr(0xf298)
ENVIRA = chr(0xf299)
UNIVERSAL_ACCESS = chr(0xf29a)
WHEELCHAIR_ALT = chr(0xf29b)
QUESTION_CIRCLE_O = chr(0xf29c)
BLIND = chr(0xf29d)
AUDIO_DESCRIPTION = chr(0xf29e)
VOLUME_CONTROL_PHONE = chr(0xf2a0)
BRAILLE = chr(0xf2a1)
ASSISTIVE_LISTENING_SYSTEMS = chr(0xf2a2)
AMERICAN_SIGN_LANGUAGE_INTERPRETING = chr(0xf2a3)
DEAF = chr(0xf2a4)
GLIDE = chr(0xf2a5)
GLIDE_G = chr(0xf2a6)
SIGN_LANGUAGE = chr(0xf2a7)
LOW_VISION = chr(0xf2a8)
VIADEO = chr(0xf2a9)
VIADEO_SQUARE = chr(0xf2aa)
SNAPCHAT = chr(0xf2ab)
SNAPCHAT_GHOST = chr(0xf2ac)
SNAPCHAT_SQUARE = chr(0xf2ad)
PIED_PIPER = chr(0xf2ae)
FIRST_ORDER = chr(0xf2b0)
YOAST = chr(0xf2b1)
THEMEISLE = chr(0xf2b2)
GOOGLE_PLUS_OFFICIAL = chr(0xf2b3)
FONT_AWESOME = chr(0xf2b4)
HANDSHAKE_O = chr(0xf2b5)
ENVELOPE_OPEN = chr(0xf2b6)
ENVELOPE_OPEN_O = chr(0xf2b7)
LINODE = chr(0xf2b8)
ADDRESS_BOOK = chr(0xf2b9)
ADDRESS_BOOK_O = chr(0xf2ba)
ADDRESS_CARD = chr(0xf2bb)
ADDRESS_CARD_O = chr(0xf2bc)
USER_CIRCLE = chr(0xf2bd)
USER_CIRCLE_O = chr(0xf2be)
USER_O = chr(0xf2c0)
ID_BADGE = chr(0xf2c1)
ID_CARD = chr(0xf2c2)
ID_CARD_O = chr(0xf2c3)
QUORA = chr(0xf2c4)
FREE_CODE_CAMP = chr(0xf2c5)
TELEGRAM = chr(0xf2c6)
THERMOMETER_FULL = chr(0xf2c7)
THERMOMETER_THREE_QUARTERS = chr(0xf2c8)
THERMOMETER_HALF = chr(0xf2c9)
THERMOMETER_QUARTER = chr(0xf2ca)
THERMOMETER_EMPTY = chr(0xf2cb)
SHOWER = chr(0xf2cc)
BATH = chr(0xf2cd)
PODCAST = chr(0xf2ce)
WINDOW_MAXIMIZE = chr(0xf2d0)
WINDOW_MINIMIZE = chr(0xf2d1)
WINDOW_RESTORE = chr(0xf2d2)
WINDOW_CLOSE = chr(0xf2d3)
WINDOW_CLOSE_O = chr(0xf2d4)
BANDCAMP = chr(0xf2d5)
GRAV = chr(0xf2d6)
ETSY = chr(0xf2d7)
IMDB = chr(0xf2d8)
RAVELRY = chr(0xf2d9)
EERCAST = chr(0xf2da)
MICROCHIP = chr(0xf2db)
SNOWFLAKE_O = chr(0xf2dc)
SUPERPOWERS = chr(0xf2dd)
WPEXPLORER = chr(0xf2de)
MEETUP = chr(0xf2e0)



import pathlib

HERE = pathlib.Path(__file__).absolute().parent


def main(dst: pathlib.Path):
    import fontawesome47.icons

    with dst.open('w') as w:
        for item in fontawesome47.icons.get_icons():
            unicode = item['unicode']
            name = item["id"].replace('-', '_').upper()
            if name[0].isdigit():
                name = '_' + name
            w.write(f'{name} = chr(0x{unicode})\n')


main(HERE/'src/fontawesome47/icons_str.py')
